<?php
/**
 * @package     Joomla.Plugin
 * @subpackage  MoneyButton
 *
 * @copyright   Copyright (C) 2005 - 2019 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

use Joomla\CMS\Captcha\Google\HttpBridgePostRequestMethod;
use Joomla\Utilities\IpHelper;

/**
 * Moneybutton Plugin
 * @since  2.5
 */
class PlgCaptchaMoneybutton extends JPlugin
{
	/**
	 * Load the language file on instantiation.
	 *
	 * @var    boolean
	 * @since  3.1
	 */
	protected $autoloadLanguage = true;

	/**
	 * Reports the privacy related capabilities for this plugin to site administrators.
	 *
	 * @return  array
	 *
	 * @since   3.9.0
	 */
	public function onPrivacyCollectAdminCapabilities()
	{
		$this->loadLanguage();

		return array(
			JText::_('PLG_CAPTCHA_MONEYBUTTON') => array(
				JText::_('PLG_MONEYBUTTON_PRIVACY_CAPABILITY_IP_ADDRESS'),
			)
		);
	}

	/**
	 * Initialise the captcha
	 *
	 * @param   string  $id  The id of the field.
	 *
	 * @return  Boolean	True on success, false otherwise
	 *
	 * @since   2.5
	 * @throws  \RuntimeException
	 */
	public function onInit($id = 'dynamic_moneybutton_1')
	{
		//$pubkey = $this->params->get('public_key', '');

		//if ($pubkey === '')
		//{
			//throw new \RuntimeException(JText::_('PLG_MONEYBUTTON_ERROR_NO_PUBLIC_KEY'));
		//}
		return true;
	}

	/**
	 * Gets the challenge HTML
	 *
	 * @param   string  $name   The name of the field. Not Used.
	 * @param   string  $id     The id of the field.
	 * @param   string  $class  The class of the field.
	 *
	 * @return  string  The HTML to be embedded in the form.
	 *
	 * @since  2.5
	 */
	public function onDisplay($name = null, $id = 'dynamic_moneybutton_1', $class = '')
	{
		$dom = new \DOMDocument('1.0', 'UTF-8');
		$ele = $dom->createElement('div');
		$ele->setAttribute('id', $id);

		if ($this->params->get('version', '1.0') === '1.0')
		{
			$ele->setAttribute('class', $class);
		}
		else
		{
			//$ele->setAttribute('class', ((trim($class) == '') ? 'g-moneybutton' : ($class . ' g-moneybutton')));
			//$ele->setAttribute('data-sitekey', $this->params->get('public_key', ''));
			//$ele->setAttribute('data-theme', $this->params->get('theme2', 'light'));
			//$ele->setAttribute('data-size', $this->params->get('size', 'normal'));
			//$ele->setAttribute('data-tabindex', $this->params->get('tabindex', '0'));
			//$ele->setAttribute('data-callback', $this->params->get('callback', ''));
			//$ele->setAttribute('data-expired-callback', $this->params->get('expired_callback', ''));
			//$ele->setAttribute('data-error-callback', $this->params->get('error_callback', ''));
		}

		$dom->appendChild($ele);
        $return=$dom->saveHTML($ele);
		return $return.'<script src="https://www.moneybutton.com/moneybutton.js"></script>
<script>
  function displayHiddenContent (payment) 
  {
    document.getElementById("g-moneybutton-response").value = payment["userId"];
  }
</script>
<div class="money-button" data-to="'.$this->params->get('account', '').'" data-amount="'.$this->params->get('amount', '').'" data-currency="'.$this->params->get('currency', '').'" data-on-payment="displayHiddenContent"></div>
        <div id="my-hidden-content"><input type="hidden" name="g-moneybutton-response" id="g-moneybutton-response" class="g-moneybutton-response" ></div>';
	}

	/**
	 * Calls an HTTP POST function to verify if the user's guess was correct
	 *
	 * @param   string  $code  Answer provided by user. Not needed for the Moneybutton implementation
	 *
	 * @return  True if the answer is correct, false otherwise
	 *
	 * @since   2.5
	 * @throws  \RuntimeException
	 */
	public function onCheckAnswer($code = null)
	{
		$input      = \JFactory::getApplication()->input;
		
		$challenge = null;
		$response  = $input->get('g-moneybutton-response', '', 'string');
		$spam      = ($response === '');
				
		// Discard spam submissions
		if ($spam)
		{
			throw new \RuntimeException(JText::_('PLG_MONEYBUTTON_ERROR_EMPTY_SOLUTION'));
		}
        return true;
		//return $this->getResponse($privatekey, $remoteip, $response, $challenge);
	}
	

	/**
	 * Get the language tag or a custom translation
	 *
	 * @return  string
	 *
	 * @since  2.5
	 */
	private function _getLanguage()
	{
		$language = JFactory::getLanguage();

		$tag = explode('-', $language->getTag());
		$tag = $tag[0];
		$available = array('en', 'pt', 'fr', 'de', 'nl', 'ru', 'es', 'tr');

		if (in_array($tag, $available))
		{
			return "lang : '" . $tag . "',";
		}

		// If the default language is not available, let's search for a custom translation
		if ($language->hasKey('PLG_MONEYBUTTON_CUSTOM_LANG'))
		{
			$custom[] = 'custom_translations : {';
			$custom[] = "\t" . 'instructions_visual : "' . JText::_('PLG_MONEYBUTTON_INSTRUCTIONS_VISUAL') . '",';
			$custom[] = "\t" . 'instructions_audio : "' . JText::_('PLG_MONEYBUTTON_INSTRUCTIONS_AUDIO') . '",';
			$custom[] = "\t" . 'play_again : "' . JText::_('PLG_MONEYBUTTON_PLAY_AGAIN') . '",';
			$custom[] = "\t" . 'cant_hear_this : "' . JText::_('PLG_MONEYBUTTON_CANT_HEAR_THIS') . '",';
			$custom[] = "\t" . 'visual_challenge : "' . JText::_('PLG_MONEYBUTTON_VISUAL_CHALLENGE') . '",';
			$custom[] = "\t" . 'audio_challenge : "' . JText::_('PLG_MONEYBUTTON_AUDIO_CHALLENGE') . '",';
			$custom[] = "\t" . 'refresh_btn : "' . JText::_('PLG_MONEYBUTTON_REFRESH_BTN') . '",';
			$custom[] = "\t" . 'help_btn : "' . JText::_('PLG_MONEYBUTTON_HELP_BTN') . '",';
			$custom[] = "\t" . 'incorrect_try_again : "' . JText::_('PLG_MONEYBUTTON_INCORRECT_TRY_AGAIN') . '",';
			$custom[] = '},';
			$custom[] = "lang : '" . $tag . "',";

			return implode("\n", $custom);
		}

		// If nothing helps fall back to english
		return '';
	}
}
